@@ -1,6 +1,6 @@
 package Email::Sender::Transport::SMTP;
 # ABSTRACT: send email over SMTP
-$Email::Sender::Transport::SMTP::VERSION = '1.300023'; # TRIAL
+$Email::Sender::Transport::SMTP::VERSION = '1.300024'; # TRIAL
 use Moo;
 
 use Email::Sender::Failure::Multi;
@@ -8,7 +8,7 @@ use Email::Sender::Success::Partial;
 use Email::Sender::Role::HasMessage ();
 use Email::Sender::Util;
 use MooX::Types::MooseLike::Base qw(Bool Int Str HashRef);
-use Net::SMTP 3.03;
+use Net::SMTP 3.07; # SSL support, fixed datasend
 
 use utf8 (); # See below. -- rjbs, 2015-05-14
 
@@ -321,7 +321,7 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300023
+version 1.300024
 
 =head1 DESCRIPTION
 
